@@ -34,7 +34,7 @@ fn test_simplified_track() {
   }
 
 "#;
-    let track: SimplifiedTrack = serde_json::from_str(&json_str).unwrap();
+    let track: SimplifiedTrack = serde_json::from_str(json_str).unwrap();
     let duration = Duration::from_millis(276773);
     assert_eq!(track.duration, duration);
 }
@@ -64,7 +64,7 @@ fn test_public_user() {
             "uri": "spotify:user:wizzler_with_underscores"
         }
         "#;
-    let user: PublicUser = serde_json::from_str(&json_str).unwrap();
+    let user: PublicUser = serde_json::from_str(json_str).unwrap();
     // This also makes sure user IDs can have other characters, such as
     // underscores.
     assert_eq!(
@@ -99,7 +99,7 @@ fn test_private_user() {
             "uri": "spotify:user:waq5aexykhm6nlv0cnwdieng0"
           } 
         "#;
-    let private_user: PrivateUser = serde_json::from_str(&json_str).unwrap();
+    let private_user: PrivateUser = serde_json::from_str(json_str).unwrap();
     assert_eq!(private_user.country.unwrap(), Country::UnitedStates);
 }
 
@@ -132,7 +132,7 @@ fn test_full_artist() {
             "uri": "spotify:artist:0OdUWJ0sBjDrqHygGUXeCF"
         }
         "#;
-    let full_artist: FullArtist = serde_json::from_str(&json_str).unwrap();
+    let full_artist: FullArtist = serde_json::from_str(json_str).unwrap();
     assert_eq!(full_artist.name, "Band of Horses");
     assert_eq!(full_artist.followers.total, 833247);
 }
@@ -174,7 +174,7 @@ fn test_simplified_episode() {
             "uri": "spotify:episode:3brfPv3PaUhspkm1T9ZVl8"
         }
         "#;
-    let simplified_episode: SimplifiedEpisode = serde_json::from_str(&json_str).unwrap();
+    let simplified_episode: SimplifiedEpisode = serde_json::from_str(json_str).unwrap();
     assert_eq!(
         simplified_episode.release_date_precision,
         DatePrecision::Day
@@ -245,7 +245,7 @@ fn test_full_episode() {
         "uri": "spotify:episode:512ojhOuo1ktJprKbVcKyQ"
     }
         "#;
-    let full_episode: FullEpisode = serde_json::from_str(&json_str).unwrap();
+    let full_episode: FullEpisode = serde_json::from_str(json_str).unwrap();
     assert_eq!(full_episode.release_date_precision, DatePrecision::Day);
     let duration = Duration::from_millis(1502795);
     assert_eq!(full_episode.duration, duration);
@@ -260,7 +260,7 @@ fn test_copyright() {
 	} ]
 
 "#;
-    let copyrights: Vec<Copyright> = serde_json::from_str(&json_str).unwrap();
+    let copyrights: Vec<Copyright> = serde_json::from_str(json_str).unwrap();
     assert_eq!(copyrights[0]._type, CopyrightType::Performance);
 }
 
@@ -282,8 +282,9 @@ fn test_audio_analysis_section() {
             "time_signature_confidence": 1
         }
         "#;
-    let session: AudioAnalysisSection = serde_json::from_str(&json_str).unwrap();
-    assert_eq!(session.time_interval.duration, 18.32542);
+    let session: AudioAnalysisSection = serde_json::from_str(json_str).unwrap();
+    // Comparison of floating point numbers
+    assert!((session.time_interval.duration - 18.32542).abs() < f32::EPSILON);
 }
 
 #[test]
@@ -305,8 +306,9 @@ fn test_audio_analysis_segments() {
             ]
             }
             "#;
-    let segment: AudioAnalysisSegment = serde_json::from_str(&json_str).unwrap();
-    assert_eq!(segment.time_interval.start, 252.15601);
+    let segment: AudioAnalysisSegment = serde_json::from_str(json_str).unwrap();
+    // Comparison of floating point numbers
+    assert!((segment.time_interval.start - 252.156).abs() < f32::EPSILON);
 }
 
 #[test]
@@ -318,7 +320,7 @@ fn test_actions() {
             }
         }
         "#;
-    let actions: Actions = serde_json::from_str(&json_str).unwrap();
+    let actions: Actions = serde_json::from_str(json_str).unwrap();
     assert_eq!(actions.disallows[0], DisallowKey::Resuming);
 }
 
@@ -334,7 +336,7 @@ fn test_recommendations_seed() {
             "type": "ARTIST"
         }        
         "#;
-    let seed: RecommendationsSeed = serde_json::from_str(&json_str).unwrap();
+    let seed: RecommendationsSeed = serde_json::from_str(json_str).unwrap();
     assert_eq!(seed._type, RecommendationsSeedType::Artist);
 }
 
@@ -578,7 +580,7 @@ fn test_full_track() {
   "uri": "spotify:track:11dFghVXANMlKmJXsNCbNl"
 }
     "#;
-    let full_track: FullTrack = serde_json::from_str(&json).unwrap();
+    let full_track: FullTrack = serde_json::from_str(json).unwrap();
     let duration = Duration::from_millis(207959);
     assert_eq!(full_track.duration, duration);
 }
@@ -591,7 +593,7 @@ fn test_resume_point() {
         "resume_position_ms": 423432
     }   
     "#;
-    let resume_point: ResumePoint = serde_json::from_str(&json).unwrap();
+    let resume_point: ResumePoint = serde_json::from_str(json).unwrap();
     let duration = Duration::from_millis(423432);
     assert_eq!(resume_point.resume_position, duration);
 }
@@ -604,7 +606,7 @@ fn test_resume_point_negative() {
         "resume_position_ms": -1000
     }
     "#;
-    let resume_point: ResumePoint = serde_json::from_str(&json).unwrap();
+    let resume_point: ResumePoint = serde_json::from_str(json).unwrap();
     let duration = Duration::default();
     assert_eq!(resume_point.resume_position, duration);
 }
@@ -709,7 +711,7 @@ fn test_currently_playing_context() {
   "is_playing": true
 }
     "#;
-    let currently_playing_context: CurrentlyPlayingContext = serde_json::from_str(&json).unwrap();
+    let currently_playing_context: CurrentlyPlayingContext = serde_json::from_str(json).unwrap();
     let timestamp = 1607769168429;
     let second: i64 = (timestamp - timestamp % 1000) / 1000;
     let nanosecond = (timestamp % 1000) * 1000000;
@@ -824,7 +826,7 @@ fn test_current_playback_context() {
   "is_playing": true
 }
     "#;
-    let current_playback_context: CurrentPlaybackContext = serde_json::from_str(&json).unwrap();
+    let current_playback_context: CurrentPlaybackContext = serde_json::from_str(json).unwrap();
     let timestamp = 1607774342714;
     let second: i64 = (timestamp - timestamp % 1000) / 1000;
     let nanosecond = (timestamp % 1000) * 1000000;
@@ -868,7 +870,7 @@ fn test_audio_analysis_track() {
     "rhythm_version": 1
   }
   "#;
-    let audio_analysis_track: AudioAnalysisTrack = serde_json::from_str(&json).unwrap();
+    let audio_analysis_track: AudioAnalysisTrack = serde_json::from_str(json).unwrap();
     assert_eq!(audio_analysis_track.mode, Modality::Minor);
 }
 
@@ -912,7 +914,7 @@ fn test_simplified_playlist() {
     "uri": "spotify:playlist:37i9dQZF1DX8mBRYewE6or"
   } 
   "#;
-    let simplified_playlist: SimplifiedPlaylist = serde_json::from_str(&json).unwrap();
+    let simplified_playlist: SimplifiedPlaylist = serde_json::from_str(json).unwrap();
     assert_eq!(
         simplified_playlist.tracks.href,
         "https://api.spotify.com/v1/playlists/37i9dQZF1DX8mBRYewE6or/tracks"
